import { AppSettingsValue } from './app-settings-value';
/**
 * An update of a settings object.
 */
export interface AppSettingsObjectUpdate {
    /**
     * The value of the setting.
     *
     *  It defines the actual values of settings' parameters.
     *
     * The actual content depends on the object's schema.
     */
    value: AppSettingsValue;
    /**
     * The position of the updated object. The new object will be moved behind the specified one.
     *
     * **insertAfter** and **insertBefore** are evaluated together and only one of both can be set.
     *
     * If `null` and **insertBefore** 'null', the existing object keeps the current position.
     *
     * If set to empty string, the updated object will be placed in the first position.
     *
     * Only applicable for objects based on schemas with ordered objects (schema's **ordered** parameter is set to `true`).
     */
    insertAfter?: string;
    /**
     * The position of the updated object. The new object will be moved in front of the specified one.
     *
     * **insertAfter** and **insertBefore** are evaluated together and only one of both can be set.
     *
     * If `null` and **insertAfter** 'null', the existing object keeps the current position.
     *
     * If set to empty string, the updated object will be placed in the last position.
     *
     * Only applicable for objects based on schemas with ordered objects (schema's **ordered** parameter is set to `true`).
     */
    insertBefore?: string;
}
