import { AppSettingsModificationInfo } from './app-settings-modification-info';
import { AppSettingsValue } from './app-settings-value';
/**
 * An effective settings value.
 */
export interface EffectiveAppSettingsValue {
    /**
     * A short summary of settings. This can contain Markdown and will be escaped accordingly.
     */
    summary?: string;
    /**
     * A searchable summary string of the setting value. Plain text without Markdown.
     */
    searchSummary?: string;
    /**
     * The schema on which the object is based.
     */
    schemaId?: string;
    /**
     * The version of the schema on which the object is based.
     */
    schemaVersion?: string;
    /**
     * The value of the setting.
     *
     *  It defines the actual values of settings' parameters.
     *
     * The actual content depends on the object's schema.
     */
    value?: AppSettingsValue;
    /**
     * Modification information about the app setting.
     */
    modificationInfo?: AppSettingsModificationInfo;
}
