import { AnalyzerCategory } from './analyzer-category';
import { ParameterDefinition } from './parameter-definition';
/**
 * The definition of the analyzer. It describes which input and output data the analyzer accepts
 * and produces when being executed.
 */
export interface AnalyzerDefinition {
    /**
     * The uniquely identifying name of the analyzer.
     */
    name: string;
    displayName: string;
    /**
     * Detailed description of the analyzers' functionality.
     * Get the documentation of the analyzer for more information.
     */
    description?: string;
    /**
     * The category of an analyzer used to logically group different analyzers.
     */
    category?: AnalyzerCategory;
    /**
     * The type of the analyzer.
     * * IMPLEMENTED: Analyzers which have an implementation and can be executed.
     * * INTERFACE: Just an interface to be implemented or extended by other analyzer definitions.
     */
    type?: 'IMPLEMENTED' | 'INTERFACE';
    /**
     * A list of string-based labels to group and mark different analyzers.
     */
    labels?: string[];
    /**
     * The analyzer name that the current analyzer is based on. All input and output parameters are inherited.
     * Additional parameters may be present in the current analyzer.
     */
    baseAnalyzer?: string;
    input?: ParameterDefinition[];
    output?: ParameterDefinition[];
}
