import { EnumerationElement } from './enumeration-element';
import { ParameterDefinitionValueConstraints } from './parameter-definition-value-constraints';
/**
 * The definition for a single parameter, describing its name and other meta information.
 */
export interface ParameterDefinition {
    name: string;
    /**
     * The type of the parameter, indicating the format of the value to be provided.
     */
    type: 'analyzerStructure' | 'boolean' | 'dimensionQuery' | 'enumeration' | 'integer' | 'number' | 'string' | 'timeframe' | 'timeseriesArray' | 'timeseriesQuery' | 'timestamp';
    displayName: string;
    description?: string;
    /**
     * If true, this parameter is considered to be for advanced usage.
     */
    advanced?: boolean;
    /**
     * Provides extended type information for this parameter.
     * This allows additional semantics that can be utilized by analyzer consumers.
     */
    extendedType?: string;
    /**
     * Whether this parameter can be omitted when executing the analyzer.
     */
    optional: boolean;
    /**
     * Whether this parameter can have an array of values. Passing a single, non-array value is also allowed.
     */
    array: boolean;
    /**
     * The default value used when the parameter is omitted.
     */
    defaultValue?: any;
    /**
     * The maximum number of elements if the parameter is an array.
     */
    maxSize?: number;
    /**
     * Defines value constraints for string or number parameters. Not applicable to other parameter types.
     */
    valueConstraints?: ParameterDefinitionValueConstraints;
    enumerationValues?: EnumerationElement[];
    /**
     * Given the parameter is of type `structure` this property contains the sub-definition of the parameter.
     */
    fields?: ParameterDefinition[];
}
