import { ModificationInfo } from './modification-info';
import { UserContext } from './user-context';
export interface DocumentMetaData {
    /**
     * System-generated id.
     */
    id: string;
    /**
     * User-given id.
     */
    externalId?: string;
    /**
     * Name, provided by the user. The system is entirely agnostic of this value and there are no semantics attached to it.
     */
    name: string;
    /**
     * Type, provided by the user. The system is entirely agnostic of this value and there are no semantics attached to it.
     */
    type: string;
    /**
     * Description, provided by the user.
     */
    description?: string;
    /**
     * Initial value is 1. Every manipulation (of metadata or content) leads to an increment. This value is used for optimistic locking during modification operations.
     */
    version: string;
    /**
     * Unique user id derived from Authorization header.
     */
    owner: string;
    /**
     * Info related to creation and modification of the entity.
     */
    modificationInfo: ModificationInfo;
    /**
     * Indicates which operations you may apply to this document. For example, if you own the document, this array contains the values ['read', 'write', 'delete'].
     * - `read` - you may read, but not update or delete it.
     * - `write` - you may update, but not read or delete it.
     * - `delete` - you may delete, but not read or update it.
     */
    access: string[];
    /**
     * Indicates whether this document is public. Public documents can be read by every user of the environment.
     */
    isPrivate: boolean;
    /**
     * The id of the application that shipped that document. Null, if the document is not ready-made by an app.
     */
    originAppId?: string;
    /**
     * The id of the extension that shipped that document. Null, if the document is not shipped by an extension.
     */
    originExtensionId?: string;
    /**
     * User-specific information related to this document.
     */
    userContext?: UserContext;
}
