import { HookOptions } from './types/HookOptions';
/**
 * Provides the parameters for the app function
 */
export type AppFunctionParams = {
    name: string;
    data?: unknown;
    responseType?: 'json' | 'text';
};
/**
 * Call specified app function by name.
 * @param params App function params.
 * @param {HookOptions} [options={ autoFetch: true, autoFetchOnUpdate: true }] - Additional options for the react hook.
 */
export declare function useAppFunction<T = unknown>({ name, data, responseType }: AppFunctionParams, options?: HookOptions): {
    data: T | undefined;
    error: Error | undefined;
    isError: boolean;
    isLoading: boolean;
    isSuccess: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
    refetch: (...args: any[]) => Promise<T>;
    cancel: () => void;
};
