import { stateClient } from '@dynatrace-sdk/client-state';
import { HookOptions } from './types/HookOptions';
/**
 * Provides the parameters for getAppState
 */
export type AppStateParams = Omit<Parameters<typeof stateClient.getAppState>[0], 'abortSignal'>;
/**
 * Gets app state
 * @param params Parameters for the client sdk call.
 * @param {HookOptions} [options={ autoFetch: true, autoFetchOnUpdate: true }] - Additional options for the react hook.
 */
export declare function useAppState(params: AppStateParams, options?: HookOptions): {
    data: import("@dynatrace-sdk/client-state").AppState | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-state").Error;
    isError: boolean;
    isLoading: boolean;
    isSuccess: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
    refetch: (...args: string[]) => Promise<import("@dynatrace-sdk/client-state").AppState>;
    cancel: () => void;
};
/**
 * Provides the parameters for getAppStates
 */
export type AppStatesParams = Omit<Parameters<typeof stateClient.getAppStates>[0], 'abortSignal'>;
/**
 * List app states
 * @param params Parameters for the client sdk call.
 * @param {HookOptions} [options={ autoFetch: true, autoFetchOnUpdate: true }] - Additional options for the react hook.
 * */
export declare function useAppStates(params: AppStatesParams, options?: HookOptions): {
    data: import("@dynatrace-sdk/client-state").AppStates | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-state").Error;
    isError: boolean;
    isLoading: boolean;
    isSuccess: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
    refetch: (...args: string[]) => Promise<import("@dynatrace-sdk/client-state").AppStates>;
    cancel: () => void;
};
/**
 * Provides the parameters for getUserAppState
 */
export type UserAppStateParams = Omit<Parameters<typeof stateClient.getUserAppState>[0], 'abortSignal'>;
/**
 * Get user app state
 * @param params Parameters for the client sdk call.
 * @param {HookOptions} [options={ autoFetch: true, autoFetchOnUpdate: true }] - Additional options for the react hook.
 */
export declare function useUserAppState(params: UserAppStateParams, options?: HookOptions): {
    data: import("@dynatrace-sdk/client-state").UserAppState | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-state").Error;
    isError: boolean;
    isLoading: boolean;
    isSuccess: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
    refetch: (...args: string[]) => Promise<import("@dynatrace-sdk/client-state").UserAppState>;
    cancel: () => void;
};
/**
 * Provides the parameters for getUserAppStates
 */
export type UserAppStatesParams = Omit<Parameters<typeof stateClient.getUserAppStates>[0], 'abortSignal'>;
/**
 * List user app states
 * @param params Parameters for the client sdk call.
 * @param {HookOptions} [options={ autoFetch: true, autoFetchOnUpdate: true }] - Additional options for the react hook.
 */
export declare function useUserAppStates(params: UserAppStatesParams, options?: HookOptions): {
    data: import("@dynatrace-sdk/client-state").UserAppStates | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-state").Error;
    isError: boolean;
    isLoading: boolean;
    isSuccess: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
    refetch: (...args: string[]) => Promise<import("@dynatrace-sdk/client-state").UserAppStates>;
    cancel: () => void;
};
/**
 * Provides the parameters for deleteAppState
 */
export type DeleteAppStateParams = Omit<Parameters<typeof stateClient.deleteAppState>[0], 'abortSignal'>;
/**
 * Deletes app state
 */
export declare function useDeleteAppState(): {
    execute: (params: DeleteAppStateParams) => Promise<void>;
    data: void | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-state").Error;
    isError: boolean;
    isSuccess: boolean;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
/**
 * Delete all app states
 */
export declare function useDeleteAppStates(): {
    execute: () => Promise<void>;
    data: void | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-state").Error;
    isError: boolean;
    isSuccess: boolean;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
/**
 * Provides the parameters for deleteUserAppState
 */
export type DeleteUserAppStateParams = Omit<Parameters<typeof stateClient.deleteUserAppState>[0], 'abortSignal'>;
/**
 * Delete user app state
 */
export declare function useDeleteUserAppState(): {
    execute: (params: DeleteUserAppStateParams) => Promise<void>;
    data: void | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-state").Error;
    isError: boolean;
    isSuccess: boolean;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
/**
 * Delete all user app states
 */
export declare function useDeleteUserAppStates(): {
    execute: () => Promise<void>;
    data: void | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-state").Error;
    isError: boolean;
    isSuccess: boolean;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
/**
 * Provides the parameters for setAppState
 */
export type SetAppStateParams = Omit<Parameters<typeof stateClient.setAppState>[0], 'abortSignal'>;
/**
 * Updates app state
 */
export declare function useSetAppState(): {
    execute: (params: SetAppStateParams) => Promise<void>;
    data: void | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-state").Error;
    isError: boolean;
    isSuccess: boolean;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
/**
 * Provides the parameters for setUserAppState
 */
export type SetAppUserStateParams = Omit<Parameters<typeof stateClient.setUserAppState>[0], 'abortSignal'>;
/**
 * Updates user app state
 */
export declare function useSetUserAppState(): {
    execute: (params: SetAppUserStateParams) => Promise<void>;
    data: void | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-state").Error;
    isError: boolean;
    isSuccess: boolean;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
