import { queryExecutionClient, QueryResult } from '@dynatrace-sdk/client-query';
import { HookOptions } from './types/HookOptions';
/**
 * Provides the parameters for queryExecute
 */
export type QueryParams = Omit<Parameters<typeof queryExecutionClient.queryExecute>[0], 'abortSignal'>;
/**
 * Use this hook to execute a DQL query.
 * @param params Query and enrich options that will be executed.
 * @param {HookOptions} [options={ autoFetch: true, autoFetchOnUpdate: true }] - Additional options for the react hook.
 * @returns The state of the query, including the result and functions to refetch or cancel the query.
 */
export declare function useDqlQuery(params: QueryParams, options?: HookOptions): {
    data: QueryResult | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-query").ErrorResponse | undefined;
    isError: boolean;
    isLoading: boolean;
    isSuccess: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
    refetch: (...args: any[]) => Promise<QueryResult | undefined>;
    cancel: () => void;
};
