import { appSettingsObjectsClient } from '@dynatrace-sdk/client-app-settings';
import { HookOptions } from './types/HookOptions';
type DistributiveOmit<T, K extends keyof any> = T extends any ? Omit<T, K> : never;
export type SettingsParams = DistributiveOmit<Parameters<typeof appSettingsObjectsClient.getEffectiveAppSettingsValues>[0], 'abortSignal'>;
/**
 * Retrieve metadata and content for settings.
 * @param params Parameters for the client sdk call.
 * @param {HookOptions} [options={ autoFetch: true, autoFetchOnUpdate: true }] - Additional options for the react hook.
 */
export declare function useSettings(params: SettingsParams, options?: HookOptions): {
    data: import("@dynatrace-sdk/client-app-settings").EffectiveAppSettingsValuesList | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings").AppSettingsError | undefined;
    isError: boolean;
    isLoading: boolean;
    isSuccess: false | import("@dynatrace-sdk/client-app-settings").EffectiveAppSettingsValuesList | undefined;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
    refetch: (...args: string[]) => Promise<import("@dynatrace-sdk/client-app-settings").EffectiveAppSettingsValuesList>;
    cancel: () => void;
};
export type SettingsObjectParams = DistributiveOmit<Parameters<typeof appSettingsObjectsClient.getAppSettingsObjects>[0], 'abortSignal'>;
/**
 * Retrieve metadata and content for settings.
 * @param params Parameters for the client sdk call.
 * @param {HookOptions} [options={ autoFetch: true, autoFetchOnUpdate: true }] - Additional options for the react hook.
 */
export declare function useSettingsObjects(params: SettingsObjectParams, options?: HookOptions): {
    data: import("@dynatrace-sdk/client-app-settings").AppSettingsObjectsList | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings").AppSettingsError | undefined;
    isError: boolean;
    isLoading: boolean;
    isSuccess: false | import("@dynatrace-sdk/client-app-settings").AppSettingsObjectsList | undefined;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
    refetch: (...args: string[]) => Promise<import("@dynatrace-sdk/client-app-settings").AppSettingsObjectsList>;
    cancel: () => void;
};
export type EffectivePermissionsParams = DistributiveOmit<Parameters<typeof appSettingsObjectsClient.resolveEffectivePermissions>[0], 'abortSignal'>;
/**
 * Retrieve effective settings permissions for the calling user.
 * @param params Parameters for the client sdk call.
 * @param {HookOptions} [options={ autoFetch: true, autoFetchOnUpdate: true }] - Additional options for the react hook.
 */
export declare function useEffectivePermissions(params: EffectivePermissionsParams, options?: HookOptions): {
    data: import("@dynatrace-sdk/client-app-settings").EffectivePermissions | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings").AppSettingsError | undefined;
    isError: boolean;
    isLoading: boolean;
    isSuccess: false | import("@dynatrace-sdk/client-app-settings").EffectivePermissions | undefined;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
    refetch: (...args: string[]) => Promise<import("@dynatrace-sdk/client-app-settings").EffectivePermissions>;
    cancel: () => void;
};
/**
 * Provides the parameters for deleteAppSettingsObjectByObjectId
 */
export type DeleteSettingsParams = DistributiveOmit<Parameters<typeof appSettingsObjectsClient.deleteAppSettingsObjectByObjectId>[0], 'abortSignal'>;
/**
 * Delete the setting
 */
export declare function useDeleteSettings(): {
    execute: (params: Omit<{
        objectId: string;
        optimisticLockingVersion: string;
        abortSignal?: import("@dynatrace-sdk/http-client").AbortSignal | undefined;
    }, "abortSignal">) => Promise<void>;
    data: void | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings").AppSettingsError | undefined;
    isError: boolean;
    isSuccess: false | void | undefined;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
/**
 * Provides the parameters for putAppSettingsObjectByObjectId
 */
export type UpdateSettingsParams = Omit<Parameters<typeof appSettingsObjectsClient.putAppSettingsObjectByObjectId>[0], 'abortSignal'>;
/**
 * Update metadata and content.
 */
export declare function useUpdateSettings(): {
    execute: (params: UpdateSettingsParams) => Promise<void>;
    data: void | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings").AppSettingsError | undefined;
    isError: boolean;
    isSuccess: false | void | undefined;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
/**
 * Provides the parameters for postAppSettingsObject
 */
export type CreateSettingsParams = Omit<Parameters<typeof appSettingsObjectsClient.postAppSettingsObject>[0], 'abortSignal'>;
/**
 * Create a new setting.
 */
export declare function useCreateSettings(): {
    execute: (params: CreateSettingsParams) => Promise<void>;
    data: void | import("@dynatrace-sdk/client-app-settings").AppSettingsObjectResponse | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings").AppSettingsError | undefined;
    isError: boolean;
    isSuccess: false | void | import("@dynatrace-sdk/client-app-settings").AppSettingsObjectResponse | undefined;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
export {};
