import { appSettingsObjectsClient } from '@dynatrace-sdk/client-app-settings-v2';
import { HookOptions } from './types/HookOptions';
type DistributiveOmit<T, K extends keyof any> = T extends any ? Omit<T, K> : never;
export type SettingsParamsV2 = DistributiveOmit<Parameters<typeof appSettingsObjectsClient.getEffectiveAppSettingsValues>[0], 'abortSignal'>;
/**
 * Retrieve metadata and content for settings.
 * @param params Parameters for the client sdk call.
 * @param {HookOptions} [options={ autoFetch: true, autoFetchOnUpdate: true }] - Additional options for the react hook.
 */
export declare function useSettingsV2(params: SettingsParamsV2, options?: HookOptions): {
    data: import("@dynatrace-sdk/client-app-settings-v2").EffectiveAppSettingsValuesList | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings-v2").Error | undefined;
    isError: boolean;
    isLoading: boolean;
    isSuccess: false | import("@dynatrace-sdk/client-app-settings-v2").EffectiveAppSettingsValuesList | undefined;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
    refetch: (...args: string[]) => Promise<import("@dynatrace-sdk/client-app-settings-v2").EffectiveAppSettingsValuesList>;
    cancel: () => void;
};
export type SettingsObjectParamsV2 = DistributiveOmit<Parameters<typeof appSettingsObjectsClient.getAppSettingsObjects>[0], 'abortSignal'>;
/**
 * Retrieve metadata and content for settings.
 * @param params Parameters for the client sdk call.
 * @param {HookOptions} [options={ autoFetch: true, autoFetchOnUpdate: true }] - Additional options for the react hook.
 */
export declare function useSettingsObjectsV2(params: SettingsObjectParamsV2, options?: HookOptions): {
    data: import("@dynatrace-sdk/client-app-settings-v2").AppSettingsObjectsList | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings-v2").Error | undefined;
    isError: boolean;
    isLoading: boolean;
    isSuccess: false | import("@dynatrace-sdk/client-app-settings-v2").AppSettingsObjectsList | undefined;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
    refetch: (...args: string[]) => Promise<import("@dynatrace-sdk/client-app-settings-v2").AppSettingsObjectsList>;
    cancel: () => void;
};
export type EffectivePermissionsParamsV2 = DistributiveOmit<Parameters<typeof appSettingsObjectsClient.resolveEffectivePermissions>[0], 'abortSignal'>;
/**
 * Retrieve effective settings permissions for the calling user.
 * @param params Parameters for the client sdk call.
 * @param {HookOptions} [options={ autoFetch: true, autoFetchOnUpdate: true }] - Additional options for the react hook.
 */
export declare function useEffectivePermissionsV2(params: EffectivePermissionsParamsV2, options?: HookOptions): {
    data: import("@dynatrace-sdk/client-app-settings-v2").EffectivePermissions | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings-v2").Error | undefined;
    isError: boolean;
    isLoading: boolean;
    isSuccess: false | import("@dynatrace-sdk/client-app-settings-v2").EffectivePermissions | undefined;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
    refetch: (...args: string[]) => Promise<import("@dynatrace-sdk/client-app-settings-v2").EffectivePermissions>;
    cancel: () => void;
};
/**
 * Provides the parameters for deleteAppSettingsObjectByObjectId
 */
export type DeleteSettingsParamsV2 = DistributiveOmit<Parameters<typeof appSettingsObjectsClient.deleteAppSettingsObjectByObjectId>[0], 'abortSignal'>;
/**
 * Delete the setting
 */
export declare function useDeleteSettingsV2(): {
    execute: (params: Omit<{
        objectId: string;
        optimisticLockingVersion: string;
        adminAccess?: boolean | undefined;
        abortSignal?: import("@dynatrace-sdk/http-client").AbortSignal | undefined;
    }, "abortSignal">) => Promise<void>;
    data: void | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings-v2").Error | undefined;
    isError: boolean;
    isSuccess: false | void | undefined;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
/**
 * Provides the parameters for putAppSettingsObjectByObjectId
 */
export type UpdateSettingsParamsV2 = Omit<Parameters<typeof appSettingsObjectsClient.putAppSettingsObjectByObjectId>[0], 'abortSignal'>;
/**
 * Update metadata and content.
 */
export declare function useUpdateSettingsV2(): {
    execute: (params: UpdateSettingsParamsV2) => Promise<void>;
    data: import("@dynatrace-sdk/client-app-settings-v2").AppSettingsUpdateResponse | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings-v2").Error | undefined;
    isError: boolean;
    isSuccess: false | import("@dynatrace-sdk/client-app-settings-v2").AppSettingsUpdateResponse | undefined;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
/**
 * Provides the parameters for postAppSettingsObject
 */
export type CreateSettingsParamsV2 = Omit<Parameters<typeof appSettingsObjectsClient.postAppSettingsObject>[0], 'abortSignal'>;
/**
 * Create a new setting.
 */
export declare function useCreateSettingsV2(): {
    execute: (params: CreateSettingsParamsV2) => Promise<void>;
    data: void | import("@dynatrace-sdk/client-app-settings-v2").AppSettingsObjectResponse | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings-v2").Error | undefined;
    isError: boolean;
    isSuccess: false | void | import("@dynatrace-sdk/client-app-settings-v2").AppSettingsObjectResponse | undefined;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
/**
 * Provides the parameters for postAppSettingsOwnershipByObjectId
 */
export type TransferOwnershipParamsV2 = Omit<Parameters<typeof appSettingsObjectsClient.postAppSettingsOwnershipByObjectId>[0], 'abortSignal'>;
/**
 * Transfer ownership.
 */
export declare function useTransferOwnershipV2(): {
    execute: (params: TransferOwnershipParamsV2) => Promise<void>;
    data: void | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings-v2").Error | undefined;
    isError: boolean;
    isSuccess: false | void | undefined;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
/**
 * Provides the parameters for getAppSettingsPermissionByObjectIdAndAccessorId
 */
export type AccessorPermissionsParamsV2 = Omit<Parameters<typeof appSettingsObjectsClient.getAppSettingsPermissionByObjectIdAndAccessorId>[0], 'abortSignal'>;
/**
 * Load accessor permissions.
 * @param params Parameters for the client sdk call.
 * @param {HookOptions} [options={ autoFetch: true, autoFetchOnUpdate: true }] - Additional options for the react hook.
 */
export declare function useAccessorPermissionsV2(params: AccessorPermissionsParamsV2, options?: HookOptions): {
    data: import("@dynatrace-sdk/client-app-settings-v2").AppSettingsAccessorPermissions | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings-v2").Error | undefined;
    isError: boolean;
    isLoading: boolean;
    isSuccess: false | import("@dynatrace-sdk/client-app-settings-v2").AppSettingsAccessorPermissions | undefined;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
    refetch: (...args: string[]) => Promise<import("@dynatrace-sdk/client-app-settings-v2").AppSettingsAccessorPermissions>;
    cancel: () => void;
};
/**
 * Provides the parameters for putAppSettingsPermissionByObjectIdAndAccessorId
 */
export type UpdateAccessorPermissionsParamsV2 = Omit<Parameters<typeof appSettingsObjectsClient.putAppSettingsPermissionByObjectIdAndAccessorId>[0], 'abortSignal'>;
/**
 * Update accessor permissions.
 */
export declare function useUpdateAccessorPermissionsV2(): {
    execute: (params: UpdateAccessorPermissionsParamsV2) => Promise<void>;
    data: void | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings-v2").Error | undefined;
    isError: boolean;
    isSuccess: false | void | undefined;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
/**
 * Provides the parameters for deleteAppSettingsPermissionByObjectIdAndAccessorId
 */
export type DeleteAccessorPermissionsParamsV2 = DistributiveOmit<Parameters<typeof appSettingsObjectsClient.deleteAppSettingsPermissionByObjectIdAndAccessorId>[0], 'abortSignal'>;
/**
 * Delete the accessor permissions
 */
export declare function useDeleteAccessorPermissionsV2(): {
    execute: (params: Omit<{
        objectId: string;
        accessorType: "user" | "group";
        accessorId: string;
        adminAccess?: boolean | undefined;
        abortSignal?: import("@dynatrace-sdk/http-client").AbortSignal | undefined;
    }, "abortSignal">) => Promise<void>;
    data: void | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings-v2").Error | undefined;
    isError: boolean;
    isSuccess: false | void | undefined;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
/**
 * Provides the parameters for getAppSettingsPermissionsByObjectId
 */
export type PermissionsParamsV2 = Omit<Parameters<typeof appSettingsObjectsClient.getAppSettingsPermissionsByObjectId>[0], 'abortSignal'>;
/**
 * Load permissions.
 * @param params Parameters for the client sdk call.
 * @param {HookOptions} [options={ autoFetch: true, autoFetchOnUpdate: true }] - Additional options for the react hook.
 */
export declare function usePermissionsV2(params: PermissionsParamsV2, options?: HookOptions): {
    data: import("@dynatrace-sdk/client-app-settings-v2").AppSettingsAccessorPermissionsList | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings-v2").Error | undefined;
    isError: boolean;
    isLoading: boolean;
    isSuccess: false | import("@dynatrace-sdk/client-app-settings-v2").AppSettingsAccessorPermissionsList | undefined;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
    refetch: (...args: string[]) => Promise<import("@dynatrace-sdk/client-app-settings-v2").AppSettingsAccessorPermissionsList>;
    cancel: () => void;
};
/**
 * Provides the parameters for postAppSettingsPermissionByObjectId
 */
export type CreatePermissionsParamsV2 = Omit<Parameters<typeof appSettingsObjectsClient.postAppSettingsPermissionByObjectId>[0], 'abortSignal'>;
/**
 * Create a new permissions.
 */
export declare function useCreatePermissionsV2(): {
    execute: (params: CreatePermissionsParamsV2) => Promise<void>;
    data: import("@dynatrace-sdk/client-app-settings-v2").AppSettingsAccessorPermissions | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings-v2").Error | undefined;
    isError: boolean;
    isSuccess: false | import("@dynatrace-sdk/client-app-settings-v2").AppSettingsAccessorPermissions | undefined;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
/**
 * Provides the parameters for getAppSettingsAllUsersPermissionByObjectId
 */
export type LoadAllUsersPermissionsParamsV2 = Omit<Parameters<typeof appSettingsObjectsClient.getAppSettingsAllUsersPermissionByObjectId>[0], 'abortSignal'>;
/**
 * Load all-users permissions.
 * @param params Parameters for the client sdk call.
 * @param {HookOptions} [options={ autoFetch: true, autoFetchOnUpdate: true }] - Additional options for the react hook.
 */
export declare function useAllUsersPermissionsV2(params: LoadAllUsersPermissionsParamsV2, options?: HookOptions): {
    data: import("@dynatrace-sdk/client-app-settings-v2").AppSettingsAccessorPermissions | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings-v2").Error | undefined;
    isError: boolean;
    isLoading: boolean;
    isSuccess: false | import("@dynatrace-sdk/client-app-settings-v2").AppSettingsAccessorPermissions | undefined;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
    refetch: (...args: string[]) => Promise<import("@dynatrace-sdk/client-app-settings-v2").AppSettingsAccessorPermissions>;
    cancel: () => void;
};
/**
 * Provides the parameters for putAppSettingsAllUsersPermissionByObjectId
 */
export type UpdateAllUsersPermissionsParamsV2 = Omit<Parameters<typeof appSettingsObjectsClient.putAppSettingsAllUsersPermissionByObjectId>[0], 'abortSignal'>;
/**
 * Update all-users permissions.
 */
export declare function useUpdateAllUsersPermissionsV2(): {
    execute: (params: UpdateAllUsersPermissionsParamsV2) => Promise<void>;
    data: void | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings-v2").Error | undefined;
    isError: boolean;
    isSuccess: false | void | undefined;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
/**
 * Provides the parameters for deleteAppSettingsAllUsersPermissionByObjectId
 */
export type DeleteAllUsersPermissionsParamsV2 = DistributiveOmit<Parameters<typeof appSettingsObjectsClient.deleteAppSettingsAllUsersPermissionByObjectId>[0], 'abortSignal'>;
/**
 * Delete the all-users permissions
 */
export declare function useDeleteAllUsersPermissionsV2(): {
    execute: (params: Omit<{
        objectId: string;
        adminAccess?: boolean | undefined;
        abortSignal?: import("@dynatrace-sdk/http-client").AbortSignal | undefined;
    }, "abortSignal">) => Promise<void>;
    data: void | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-app-settings-v2").Error | undefined;
    isError: boolean;
    isSuccess: false | void | undefined;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
export {};
